==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/newlife/leechcraft_newlife_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>FeedsSettingsImportPage</name>
    <message>
        <location filename="feedssettingsimportpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="22"/>
        <source>Location:</source>
        <translation>Место:</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="34"/>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="45"/>
        <source>Import %1 settings as well</source>
        <extracomment>Application&apos;s name will be placed instead of %1, so please leave it where appropriate.</extracomment>
        <translation>Также импортировать настройки %1</translation>
    </message>
</context>
<context>
    <name>FirstPage</name>
    <message>
        <location filename="firstpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="17"/>
        <source>Choose application</source>
        <translation>Выбор приложения</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="20"/>
        <source>Choose appication that you want your data to be imported from</source>
        <translation>Выберите приложение, из которого будет произведен импорт</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="28"/>
        <source>Source application:</source>
        <translation>Исходное приложение:</translation>
    </message>
</context>
<context>
    <name>ImportWizard</name>
    <message>
        <location filename="importwizard.ui" line="14"/>
        <source>Wizard</source>
        <translation>Мастер</translation>
    </message>
    <message>
        <location filename="importwizard.ui" line="35"/>
        <source>Now please prepare for the import of data from the selected application.</source>
        <translation>Теперь, пожалуйста, приготовтесь к импорту данных из выбранного приложения.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::AkregatorImportPage</name>
    <message>
        <location filename="akregatorimportpage.cpp" line="40"/>
        <source>Akregator&apos;s feeds import</source>
        <translation>Импорт фидов из Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="41"/>
        <source>Select Akregator&apos;s feeds file and options</source>
        <translation>Выберите файл с фидами Akregator&apos;а и опции</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="103"/>
        <source>Select Akregator&apos;s OPML file</source>
        <translation>Выбор OPML-файла Akregator&apos;а</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="105"/>
        <source>OPML files (*.opml *.xml);;All files (*.*)</source>
        <translation>Файлы OPML (*.opml *.xml);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="111"/>
        <location filename="akregatorimportpage.cpp" line="159"/>
        <source>LeechCraft</source>
        <translation>LeechCraft</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="112"/>
        <source>The file you&apos;ve selected is not a valid OPML file.</source>
        <translation>Файл, выбранный вами, не является валидным OPML-файлом.</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="155"/>
        <source>Akregator settings</source>
        <translation>Настройки Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="160"/>
        <source>Could not access or parse Akregator settings.</source>
        <translation>Невозможно получить доступ либо разобрать настройки Akregator.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::LifereaImportPage</name>
    <message>
        <location filename="lifereaimportpage.cpp" line="40"/>
        <source>Liferea&apos;s feeds import</source>
        <translation>Импорт фидов из Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="41"/>
        <source>Select Liferea&apos;s base location and options</source>
        <translation>Выберите базовое положение директории Liferea и настройки</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="108"/>
        <source>Select Liferea&apos;s directory</source>
        <translation>Выбор директории Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="116"/>
        <source>LeechCraft</source>
        <translation>LeechCraft</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="117"/>
        <source>The directory you&apos;ve selected is not Liferea&apos;s directory.</source>
        <translation>Выбранная вами директория не является директорией LIferea.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::Plugin</name>
    <message>
        <location filename="newlife.cpp" line="49"/>
        <source>The settings importer.</source>
        <translation>Импортер настроек.</translation>
    </message>
    <message>
        <location filename="newlife.cpp" line="83"/>
        <source>Import settings...</source>
        <translation>Импортировать настройки...</translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/newlife/leechcraft_newlife_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>FeedsSettingsImportPage</name>
    <message>
        <location filename="feedssettingsimportpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation></translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="22"/>
        <source>Location:</source>
        <translation>Место:</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="34"/>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="45"/>
        <source>Import %1 settings as well</source>
        <extracomment>Application&apos;s name will be placed instead of %1, so please leave it where appropriate.</extracomment>
        <translation>Также импортировать настройки %1</translation>
    </message>
</context>
<context>
    <name>FirstPage</name>
    <message>
        <location filename="firstpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation></translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="17"/>
        <source>Choose application</source>
        <translation>Выбор приложения</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="20"/>
        <source>Choose appication that you want your data to be imported from</source>
        <translation>Выберите приложение, из которого будет произведен импорт</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="28"/>
        <source>Source application:</source>
        <translation>Исходное приложение:</translation>
    </message>
</context>
<context>
    <name>ImportWizard</name>
    <message>
        <location filename="importwizard.ui" line="14"/>
        <source>Wizard</source>
        <translation>Мастер</translation>
    </message>
    <message>
        <location filename="importwizard.ui" line="35"/>
        <source>Now please prepare for the import of data from the selected application.</source>
        <translation>Теперь, пожалуйста, приготовтесь к импорту данных из выбранного приложения.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::AkregatorImportPage</name>
    <message>
        <location filename="akregatorimportpage.cpp" line="40"/>
        <source>Akregator&apos;s feeds import</source>
        <translation>Импорт фидов из Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="41"/>
        <source>Select Akregator&apos;s feeds file and options</source>
        <translation>Выберите файл с фидами Akregator&apos;а и опции</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="103"/>
        <source>Select Akregator&apos;s OPML file</source>
        <translation>Выбор OPML-файла Akregator&apos;а</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="105"/>
        <source>OPML files (*.opml *.xml);;All files (*.*)</source>
        <translation>Файлы OPML (*.opml *.xml);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="112"/>
        <source>The file you&apos;ve selected is not a valid OPML file.</source>
        <translation>Файл, выбранный вами, не является валидным OPML-файлом.</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="155"/>
        <source>Akregator settings</source>
        <translation>Настройки Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="160"/>
        <source>Could not access or parse Akregator settings.</source>
        <translation>Невозможно получить доступ либо разобрать настройки Akregator.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::KTorrentImportPage</name>
    <message>
        <location filename="ktorrentimportpage.cpp" line="41"/>
        <source>KTorrent&apos;s torrents import</source>
        <translation>Импорт торрентов из KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="42"/>
        <source>Select KTorrent&apos;s torrents</source>
        <translation>Выберите торренты KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="85"/>
        <source>Select KTorrent&apos;s configuration file</source>
        <translation>Выберите конфигурационный файл KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="95"/>
        <source>Can&apos;t read KTorrent&apos;s configuration file</source>
        <translation>Невозможно прочитать конфигурационный файл KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="182"/>
        <source>KTorrent settings</source>
        <translation>Настройки KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="187"/>
        <source>Could not access or parse KTorrent settings.</source>
        <translation>Невозможно прочесть настройки KTorrent.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::LifereaImportPage</name>
    <message>
        <location filename="lifereaimportpage.cpp" line="40"/>
        <source>Liferea&apos;s feeds import</source>
        <translation>Импорт фидов из Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="41"/>
        <source>Select Liferea&apos;s base location and options</source>
        <translation>Выберите базовое положение директории Liferea и настройки</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="108"/>
        <source>Select Liferea&apos;s directory</source>
        <translation>Выбор директории Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="117"/>
        <source>The directory you&apos;ve selected is not Liferea&apos;s directory.</source>
        <translation>Выбранная вами директория не является директорией LIferea.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::Plugin</name>
    <message>
        <location filename="newlife.cpp" line="53"/>
        <source>The settings importer.</source>
        <translation>Импортер настроек.</translation>
    </message>
    <message>
        <location filename="newlife.cpp" line="87"/>
        <source>Import settings...</source>
        <translation>Импортировать настройки...</translation>
    </message>
</context>
</TS>
